@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: AddressRange.cpp,v 1.2 2004/09/08 05:34:50 vkurland Exp $
+  $Id: AddressRange.cpp,v 1.3 2006/09/10 22:40:36 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -35,20 +35,19 @@ using namespace libfwbuilder;
 const char *AddressRange::TYPENAME={"AddressRange"};
 
 AddressRange::AddressRange() : Address() , 
-		     start_address("0.0.0.0") , 
-		     end_address("0.0.0.0")
+                               start_address("0.0.0.0") , 
+                               end_address("0.0.0.0")
 {
 }
 
-AddressRange::AddressRange(const FWObject *root) : Address() , 
-						   start_address("0.0.0.0") , 
-						   end_address("0.0.0.0")
+AddressRange::AddressRange(const FWObject *root,bool prepopulate) :
+    Address(root,prepopulate) , start_address("0.0.0.0") , end_address("0.0.0.0")
 {
 }
 
 AddressRange::AddressRange(AddressRange &o) : Address() , 
-			       start_address(o.getRangeStart()) , 
-			       end_address(o.getRangeEnd()) 
+                                              start_address(o.getRangeStart()) , 
+                                              end_address(o.getRangeEnd()) 
 {
     FWObject::operator=(o);
 }
