@@ -7,7 +7,7 @@
   Author:  Vadim Kurland     vadim@vk.crocodile.org
            Vadim Zaliva      lord@crocodile.org
 
-  $Id: BackgroundOp.cpp,v 1.3 2006/06/25 04:31:26 vkurland Exp $
+  $Id: BackgroundOp.cpp,v 1.4 2007/08/02 05:19:28 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -142,7 +142,9 @@ void BackgroundOp::stop_operation()
     stop_program->unlock();
 }
 
-void *libfwbuilder::background_thread(void *args)
+namespace libfwbuilder
+{
+void *background_thread(void *args)
 {
     void **void_pair=(void**)args;
 
@@ -165,7 +167,7 @@ void *libfwbuilder::background_thread(void *args)
             delete void_pair;
             return(NULL); 
         }
-        *logger << "Exception: " << ex.toString() << '\n';
+        *logger << "Exception: " << ex.toString().c_str() << '\n';
         bop->error=new FWException(ex);
         isdead->unlock();
     }
@@ -212,6 +214,7 @@ void *libfwbuilder::background_thread(void *args)
     return(NULL);
 }
 
+}
 
 
 
