@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: CustomService.cpp,v 1.3 2004/12/01 07:27:44 vkurland Exp $
+  $Id: CustomService.cpp,v 1.4 2006/09/10 22:40:36 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -38,7 +38,8 @@ using namespace libfwbuilder;
 const char *CustomService::TYPENAME={"CustomService"};
 
 CustomService::CustomService() {}
-CustomService::CustomService(const FWObject *root) : Service(root) {}
+CustomService::CustomService(const FWObject *root,bool prepopulate) :
+    Service(root,prepopulate) {}
 CustomService::~CustomService() {}
 
 string CustomService::getProtocolName()     {    return "custom_service";}
