@@ -6,7 +6,7 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: DNSName.h,v 1.5 2006/05/17 00:20:37 vkurland Exp $
+  $Id: DNSName.h,v 1.6 2006/09/10 22:40:36 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -42,7 +42,7 @@ class DNSName : public MultiAddress
     DECLARE_FWOBJECT_SUBTYPE(DNSName);
 
     DNSName();
-    DNSName(const FWObject *root);
+    DNSName(const FWObject *root,bool prepopulate);
 
     virtual void loadFromSource() throw(FWException);
 };
