@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: FWObject.cpp,v 1.14 2006/09/20 15:38:00 vkurland Exp $
+  $Id: FWObject.cpp,v 1.15 2007/07/07 05:36:22 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -301,6 +301,8 @@ FWObject& FWObject::duplicate(const FWObject *x, bool preserve_id) throw(FWExcep
 #endif
     shallowDuplicate(x,preserve_id);
 
+    if (xro) setReadOnly(false);
+
     destroyChildren();   // does it erase index entries?
 
     for(list<FWObject*>::const_iterator m=x->begin(); m!=x->end(); ++m) 
@@ -311,6 +313,7 @@ FWObject& FWObject::duplicate(const FWObject *x, bool preserve_id) throw(FWExcep
 
     setDirty(true);
     if (xro) setReadOnly(true);
+
     return *this;
 }
 
@@ -335,6 +338,9 @@ FWObject* FWObject::addCopyOf(const FWObject *x, bool preserve_id) throw(FWExcep
  * copying an object does not copy its read-only status; thus we can
  * take read-only object and make a read-write copy of it to work
  * with.
+ *
+ * 07/06/2007 -- changed that. Now copy has the same value of "ro"
+ * attribute.  Clear it in the caller if neccessary.
  */
 FWObject& FWObject::shallowDuplicate(const FWObject *x, bool preserve_id) throw(FWException)
 {
@@ -342,8 +348,11 @@ FWObject& FWObject::shallowDuplicate(const FWObject *x, bool preserve_id) throw(
 
     string id = getId();
 
-    data     = x->data;
-    if (getBool("ro")) setReadOnly(false);
+    data = x->data;
+    bool ro_status = getBool("ro");
+    if (ro_status) setReadOnly(false);
+
+    //if (getBool("ro")) setReadOnly(false);
     if (!preserve_id)
     {
         ref_counter = 0           ;
@@ -354,6 +363,9 @@ FWObject& FWObject::shallowDuplicate(const FWObject *x, bool preserve_id) throw(
     if (dbroot==NULL) setRoot(x->getRoot());
     if (dbroot!=NULL) FWObjectDatabase::cast(dbroot)->addToIndex(this);
 
+    // do setReadOnly only if needed; this way objects that
+    // do not have this attribute won't get it accidentally.
+    if (ro_status) setReadOnly(true);
     setDirty(true);
     return *this;
 }
@@ -1052,7 +1064,9 @@ bool FWObject::isReadOnly()
 
 void FWObject::checkReadOnly() throw(FWException)
 {
-    if (isReadOnly()) throw FWException(string("Attempt to modify read-only object ")+getName());
+    if (isReadOnly())
+        throw FWException(
+            string("Attempt to modify read-only object ")+getName());
 }
 
 
