@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: Firewall.h,v 1.6 2006/04/19 15:03:21 vkurland Exp $
+  $Id: Firewall.h,v 1.7 2006/09/10 22:40:37 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -49,7 +49,7 @@ class Firewall : public Host
     public:
     
     Firewall();
-    Firewall(const FWObject *root);
+    Firewall(const FWObject *root,bool prepopulate);
     virtual ~Firewall();
     
     virtual void fromXML(xmlNodePtr parent) throw(FWException);
