@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: Interface.h,v 1.3 2006/03/06 03:00:50 vkurland Exp $
+  $Id: Interface.h,v 1.5 2007/05/10 00:53:45 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -65,7 +65,7 @@ class Interface : public Address
     public:
     
     Interface();
-    Interface(const FWObject *root);
+    Interface(const FWObject *root,bool prepopulate);
     Interface(const Interface &i);
     virtual ~Interface();
 
@@ -122,6 +122,13 @@ class Interface : public Address
     bool isRegular() const
     { return (!isDyn() && !isUnnumbered() && !isBridgePort()); }
     
+    /**
+     * set and check 'unprotected' attribute - for interfaces that
+     * should not have any ACLs or policy rules
+     */
+    void setUnprotected(bool value);
+    bool isUnprotected() const ;
+
     void setManagement(bool value);
     bool isManagement() const;
 
