@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: IntervalGroup.h,v 1.2 2004/09/08 05:34:50 vkurland Exp $
+  $Id: IntervalGroup.h,v 1.3 2006/09/10 22:40:37 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -39,7 +39,7 @@ class IntervalGroup : public Group
     public:
 
     IntervalGroup();
-    IntervalGroup(const FWObject *root);
+    IntervalGroup(const FWObject *root,bool prepopulate);
     virtual ~IntervalGroup();
 
     DECLARE_FWOBJECT_SUBTYPE(IntervalGroup);
