@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: ObjectGroup.cpp,v 1.6 2006/03/23 05:50:01 vkurland Exp $
+  $Id: ObjectGroup.cpp,v 1.7 2006/09/10 22:40:37 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -43,7 +43,8 @@ using namespace libfwbuilder;
 const char *ObjectGroup::TYPENAME={"ObjectGroup"};
 
 ObjectGroup::ObjectGroup() : Group() {}
-ObjectGroup::ObjectGroup(const FWObject *root) : Group(root) {}
+ObjectGroup::ObjectGroup(const FWObject *root,bool prepopulate) :
+    Group(root,prepopulate) {}
 
 ObjectGroup::~ObjectGroup() {}
 
