@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: RuleElement.cpp,v 1.8 2006/09/10 22:40:37 vkurland Exp $
+  $Id: RuleElement.cpp,v 1.9 2007/05/22 20:27:42 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -254,7 +254,18 @@ bool RuleElementItf::validateChild(FWObject *o)
   if (FWObjectReference::cast(o)!=NULL) return true;  //I dont like this
   if ( o->getId() == getAnyElementId()) return true;
   if (Interface::cast(o)!=NULL) return checkItfChildOfThisFw(o);
-
+  if (ObjectGroup::cast(o)!=NULL)
+  {
+      bool all_intf = true;
+      for (FWObject::iterator i=o->begin(); i!=o->end(); ++i)
+      {
+          FWObject *o1= *i;
+          if (FWReference::cast(o1)!=NULL)
+              o1=FWReference::cast(o1)->getPointer();
+          if (!Interface::isA(o1)) { all_intf = false; break; }
+      }
+      return all_intf;  // group is allowed if all members are interfaces
+  }
   return false;
 }
 
