@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: TCPService.cpp,v 1.3 2006/09/10 22:40:37 vkurland Exp $
+  $Id: TCPService.cpp,v 1.4 2007/05/08 01:26:21 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -126,6 +126,13 @@ void TCPService::fromXML(xmlNodePtr root) throw(FWException)
         FREEXMLBUFF(n);
     }
 
+    n=FROMXMLCAST(xmlGetProp(root,TOXMLCAST("established")));
+    if(n!=NULL)
+    {
+        setStr("established", n);
+        FREEXMLBUFF(n);
+    }
+
     std::map<TCPFlag,std::string>::iterator i;
     for (i=flags.begin(); i!=flags.end(); ++i)
     {
@@ -149,6 +156,16 @@ void TCPService::fromXML(xmlNodePtr root) throw(FWException)
 
 }
 
+bool  TCPService::getEstablished()
+{
+    return getBool("established");
+}
+
+void  TCPService::setEstablished(bool f)
+{
+    return setBool("established", f);
+}
+
 bool  TCPService::inspectFlags() const 
 { 
     return ( ! getAllTCPFlagMasks().empty() );
