@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: XMLTools.cpp,v 1.7 2006/05/15 04:06:08 vkurland Exp $
+  $Id: XMLTools.cpp,v 1.8 2006/08/22 04:12:49 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -217,11 +217,21 @@ void XMLTools::initXMLTools()
 
 string XMLTools::readFile(const std::string &rfile) throw(FWException)
 {
+    string buf;
     struct stat stt;
     int         fd;
 
-    if (rfile=="-") fd=0;
-    else
+    if (rfile=="-")
+    {
+        string s;
+        while (!cin.eof()) 
+        {
+            getline(cin,s);
+            buf += s;
+            buf += '\n';
+        }
+        return buf;
+    } else
     {
 #ifdef _WIN32
       if (stat( rfile.c_str() , &stt )!=0 || (fd=_open(rfile.c_str(),O_RDONLY|_O_BINARY))<0)
@@ -232,7 +242,6 @@ string XMLTools::readFile(const std::string &rfile) throw(FWException)
 
     }
 
-    string buf;
     int chunk_size = 65536;
     char *chunk = (char*)malloc(chunk_size);
     if (!chunk) throw FWException("Out of memory");
@@ -292,7 +301,8 @@ xmlDocPtr XMLTools::parseFile(const string &file_name,
     xml_parser_mutex.unlock();
     if(!doc || errors.length())
     {
-        throw FWException("Error parsing XML file: "+file_name+
+        throw FWException("Error parsing XML from file '"+file_name+ "' "+
+                          "(use_dtd="+ (use_dtd?string("1"):string("0"))+") "+
                           (errors.length()?(string("\nXML Parser reported:\n")+errors):string(""))
         );
     }
@@ -317,7 +327,7 @@ xmlDocPtr XMLTools::loadFile(const string &data_file ,
          << endl;
 #endif
     
-    if(data_file!="-" && access(data_file.c_str() , R_OK )!=0)
+    if (data_file!="-" && access(data_file.c_str() , R_OK )!=0)
         throw FWException(string("Could not access data file: ")+data_file);
 
     string buf = readFile(data_file);
@@ -328,7 +338,16 @@ xmlDocPtr XMLTools::loadFile(const string &data_file ,
 #ifdef FW_XMLTOOLS_VERBOSE
     cerr << "Parsed file: " << data_file << endl;
 #endif
-    
+
+    // normally we load the file twice, first time to check the version and
+    // upgrade it and the second time to generate doc that will be
+    // used in the program. We can't do this if data_file is '-' (stdin)
+    // 'cause we can't read stdin twice. So in this case we do not 
+    // upgrade. 
+   
+    if (data_file=="-") return doc;
+
+
     xmlDocPtr newdoc=convert(doc, data_file, type, template_dir, current_version);
     if(newdoc)
     {
@@ -378,7 +397,7 @@ in the same directory with extension '.bak'. Are you sure you want to open it?";
     } 
     assert(doc!=NULL);
     xmlFreeDoc(doc);
-    
+
     // Now we know the version is OK,
     // let us load for real, checking DTD.
     doc = parseFile(data_file, readFile(data_file), true, template_dir); 
