@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: Compiler.cpp,v 1.27 2006/09/10 22:40:37 vkurland Exp $
+  $Id: Compiler.cpp,v 1.28 2006/12/28 07:37:41 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -279,17 +279,18 @@ void Compiler::_expand_group_recursive(FWObject *o,list<FWObject*> &ol)
  * run-time address tables
  */
     MultiAddress *adt = MultiAddress::cast(o);
-    if ((Group::cast(o)!=NULL && adt==NULL) ||
-        (adt!=NULL && adt->isCompileTime()))
+    if ((Group::cast(o)!=NULL && adt==NULL) || (adt!=NULL && adt->isCompileTime()))
     {
-	for (FWObject::iterator i2=o->begin(); i2!=o->end(); ++i2) {
+	for (FWObject::iterator i2=o->begin(); i2!=o->end(); ++i2)
+        {
 	    FWObject *o1= *i2;
 	    if (FWReference::cast(o1)!=NULL) o1=FWReference::cast(o1)->getPointer();
 	    assert(o1);
 
 	    _expand_group_recursive(o1,ol);
 	}
-    } else {
+    } else
+    {
 	o->ref();
 	ol.push_back( o );
     }
@@ -302,7 +303,8 @@ void Compiler::_expand_group_recursive(FWObject *o,list<FWObject*> &ol)
 void Compiler::expandGroupsInRuleElement(RuleElement *s)
 {
     list<FWObject*> cl;
-    for (FWObject::iterator i1=s->begin(); i1!=s->end(); ++i1) {
+    for (FWObject::iterator i1=s->begin(); i1!=s->end(); ++i1)
+    {
         FWObject *o= *i1;
         if (FWReference::cast(o)!=NULL) o=FWReference::cast(o)->getPointer();
         assert(o);
@@ -310,9 +312,10 @@ void Compiler::expandGroupsInRuleElement(RuleElement *s)
     }
 
     s->clearChildren();
-    s->setAnyElement();
+    //s->setAnyElement();
 
-    for(FWObject::iterator i2=cl.begin(); i2!=cl.end(); ++i2) {
+    for(FWObject::iterator i2=cl.begin(); i2!=cl.end(); ++i2)
+    {
         s->addRef( *i2 );
     }
 }
@@ -1041,50 +1044,67 @@ bool Compiler::emptyGroupsInRE::processNext()
     {
 	FWObject *o= *i;
 	if (FWReference::cast(o)!=NULL) o=FWReference::cast(o)->getPointer();
-        if (Group::cast(o)!=NULL && MultiAddress::cast(o)==NULL && countChildren(o)==0)
+        if ( MultiAddress::cast(o)!=NULL && MultiAddress::cast(o)->isRunTime())
+            continue;
+
+        //if (Group::cast(o)!=NULL && MultiAddress::cast(o)==NULL && countChildren(o)==0)
+        if (Group::cast(o)!=NULL && countChildren(o)==0)
             cl.push_back(o);
     }
 
     if (!cl.empty())
     {
-        char str[1024];
         if ( compiler->fw->getOptionsObject()->getBool ("ignore_empty_groups") )
         {
             for (FWObject::iterator i=cl.begin(); i!=cl.end(); i++)
             {
                 FWObject *o= *i;
-                SNPRINTF(str,sizeof(str),
-                         "Empty group '%s' used in the rule %s", 
-                         o->getName().c_str(), rule->getLabel().c_str() );
+                ostringstream  str;
+                str << "Empty group or address table object '"
+                    << o->getName()
+                    << "' used in the rule "
+                    << rule->getLabel();
                 re->removeRef(o);
-                compiler->warning( str );
+                compiler->warning( str.str() );
             }
             if (re->isAny())
             {
-                SNPRINTF(str,sizeof(str),
-                         "After removal of all empty groups rule element %s becomes 'any' in the rule %s",
-                         re->getTypeName().c_str(), rule->getLabel().c_str() );
-                compiler->warning( str );
-
-                SNPRINTF(str,sizeof(str),
-                         "Dropping rule %s because option 'Ignore rules with empty groups' is in effect",
-                         rule->getLabel().c_str() );
-                compiler->warning( str );
+                ostringstream  str;
+                str << "After removal of all empty groups and address table objects rule element "
+                    << re->getTypeName()
+                    << " becomes 'any' in the rule "
+                    << rule->getLabel()
+                    << endl
+                    << "Dropping rule "
+                    <<  rule->getLabel()
+                    << " because option 'Ignore rules with empty groups' is in effect";
+                compiler->warning( str.str() );
 
                 return true; // dropping this rule
             }
         } else
         {
             std::string gr;
+            int cntr = 0;
             for (FWObject::iterator i=cl.begin(); i!=cl.end(); i++)
             {
                 FWObject *o= *i;
-                gr+=o->getName()+" ";
+                if (cntr>0) gr += ",";
+                gr += o->getName();
+                cntr++;
             }
+            string sfx = "";
+            if (cntr>0) sfx = "s";
 
-            SNPRINTF(str,sizeof(str),"Empty group(s) '%s' found in the rule %s", 
-                     gr.c_str(), rule->getLabel().c_str() );
-            compiler->abort( str );
+            ostringstream  str;
+            str << "Empty group or address table object"
+                << sfx
+                << " '"
+                << gr
+                << "' found in the rule "
+                << rule->getLabel()
+                << " and option 'Ignore rules with empty groups' is off";
+            compiler->abort( str.str() );
         }
     }
     tmp_queue.push_back(rule);
