@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler.cpp,v 1.19 2007/01/07 01:34:41 vkurland Exp $
+  $Id: PolicyCompiler.cpp,v 1.21 2007/05/22 21:33:56 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -310,24 +310,41 @@ bool  PolicyCompiler::InterfacePolicyRules::processNext()
         tmp_queue.push_back(rule);
         return true;
     }
-    if (itfre->size()==1)
+    for (FWObject::iterator i=itfre->begin(); i!=itfre->end(); ++i)
     {
-        Interface *itf = compiler->getFirstItf(rule);  assert(itf);
-        rule->setInterfaceId( itf->getId() );
-        tmp_queue.push_back(rule);
-        return true;
-    } else
-    {
-        for (FWObject::iterator i=itfre->begin(); i!=itfre->end(); ++i)
+        FWObject *o=*i;
+        if (FWReference::cast(o)!=NULL)
+            o=FWReference::cast(o)->getPointer();
+
+        if (ObjectGroup::isA(o))
         {
-            FWObject *o=*i;
-            if (FWReference::cast(o)!=NULL)
-                o=FWReference::cast(o)->getPointer();
+            // a group in "interface" rule element. GUI checks that only
+            // interfaces are allowed in such group, but we should check anyway.
+            for (FWObject::iterator i=o->begin(); i!=o->end(); ++i)
+            {
+                FWObject *o1=*i;
+                if (FWReference::cast(o1)!=NULL)
+                    o1=FWReference::cast(o1)->getPointer();
+                if (!Interface::isA(o1))
+                {
+                    compiler->warning("Object '" + o1->getName() + "', which is not an interface, is a member of the group '" + o->getName() + "' used in 'Interface' element of a rule.   Rule: " + rule->getLabel());
+                    continue;
+                }
+                PolicyRule *r= PolicyRule::cast(
+                    compiler->dbcopy->create(PolicyRule::TYPENAME) );
+                compiler->temp_ruleset->add(r);
+                r->duplicate(rule);
+                r->setInterfaceId(o1->getId());
+                tmp_queue.push_back(r);
+            }
+        } else
+        {
+
             PolicyRule *r= PolicyRule::cast(
                 compiler->dbcopy->create(PolicyRule::TYPENAME) );
+            compiler->temp_ruleset->add(r);
             r->duplicate(rule);
             r->setInterfaceId(o->getId());
-            compiler->temp_ruleset->add(r);
             tmp_queue.push_back(r);
         }
     }
@@ -503,7 +520,6 @@ bool PolicyCompiler::splitServices::processNext()
 {
     PolicyRule *rule=getNext(); if (rule==NULL) return false;
 
-
     RuleElementSrv *srv=rule->getSrv();
 
     if (srv->size()==1)
@@ -1010,6 +1026,30 @@ bool PolicyCompiler::MACFiltering::processNext()
 }
 
 
+bool PolicyCompiler::CheckForTCPEstablished::processNext()
+{
+    PolicyRule *rule=getNext(); if (rule==NULL) return false;
+
+    RuleElementSrv *srv=rule->getSrv();
+
+    for (FWObject::iterator i=srv->begin(); i!=srv->end(); i++)
+    {
+        FWObject *o= *i;
+        if (FWReference::cast(o)!=NULL) o=FWReference::cast(o)->getPointer();
+
+        TCPService *s = TCPService::cast( o );
+        if (s==NULL) continue;
+
+        if (s->getEstablished())
+            compiler->abort(string("TCPService object with option \"established\" is not supported by firewall platform \"") + compiler->myPlatformName() + string("\". Use stateful rule instead."));
+    }
+
+    tmp_queue.push_back(rule);
+    return true;
+}
+
+
+
 
 string PolicyCompiler::debugPrintRule(Rule *r)
 {
